@@ -31,16 +31,29 @@
 using namespace Qt::StringLiterals;
 
 ResourcesModel *ResourcesModel::s_self = nullptr;
+bool ResourcesModel::s_quitting = false;
 
 ResourcesModel *ResourcesModel::global()
 {
     if (!s_self) {
         s_self = new ResourcesModel;
-        s_self->init(true);
+        Q_ASSERT(!s_quitting);
+        if (!s_quitting) {
+            s_self->init(true);
+        } else {
+            // Only should happen if the singleton is instantiated after aboutToQuit
+            QTimer::singleShot(0, s_self, &ResourcesModel::destroyObject);
+        }
     }
     return s_self;
 }
 
+void ResourcesModel::destroyObject()
+{
+    s_quitting = true;
+    deleteLater();
+}
+
 ResourcesModel::ResourcesModel(QObject *parent)
     : QObject(parent)
     , m_currentApplicationBackend(nullptr)
@@ -89,9 +102,8 @@ void ResourcesModel::init(bool load)
     m_updateAction = new DiscoverAction(this);
     m_updateAction->setIconName(QStringLiteral("system-software-update"));
     m_updateAction->setText(i18n("Refresh"));
-    connect(this, &ResourcesModel::fetchingChanged, m_updateAction, [this](bool fetching) {
-        m_updateAction->setEnabled(!fetching);
-        m_fetchingUpdatesProgress.reevaluate();
+    connect(this, &ResourcesModel::fetchingUpdatesProgressChanged, m_updateAction, [this](int fetchingProgress) {
+        m_updateAction->setEnabled(fetchingProgress == 100);
     });
     connect(m_updateAction, &DiscoverAction::triggered, this, &ResourcesModel::checkForUpdates);
 
@@ -225,11 +237,6 @@ bool ResourcesModel::isInitializing() const
     return m_isInitializing;
 }
 
-bool ResourcesModel::isBusy() const
-{
-    return TransactionModel::global()->rowCount() > 0;
-}
-
 bool ResourcesModel::isExtended(const QString &id)
 {
     return std::any_of(m_backends.constBegin(), m_backends.constEnd(), [&](AbstractResourcesBackend *backend) {
@@ -390,4 +397,19 @@ void ResourcesModel::setInlineMessage(const QSharedPointer<InlineMessage> &inlin
     Q_EMIT inlineMessageChanged(inlineMessage);
 }
 
+QString ResourcesModel::remainingDescription() const
+{
+    QStringList ret;
+    for (auto backend : std::as_const(m_backends)) {
+        if (backend->fetchingUpdatesProgress() < 100) {
+            ret += i18nc("@info:status %1 is the name of a source of updates", "Refreshing %1", backend->displayName());
+        }
+    }
+    if (ret.isEmpty()) {
+        return {};
+    }
+    ret.removeDuplicates();
+    return ret.join("\n"_L1);
+}
+
 #include "moc_ResourcesModel.cpp"
