@@ -76,6 +76,7 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QObject
                    currentApplicationBackendChanged)
     Q_PROPERTY(DiscoverAction *updateAction READ updateAction CONSTANT)
     Q_PROPERTY(int fetchingUpdatesProgress READ fetchingUpdatesProgress NOTIFY fetchingUpdatesProgressChanged)
+    Q_PROPERTY(QString remainingDescription READ remainingDescription NOTIFY fetchingUpdatesProgressChanged)
     Q_PROPERTY(QString applicationSourceName READ applicationSourceName NOTIFY currentApplicationBackendChanged)
     Q_PROPERTY(InlineMessage *inlineMessage READ inlineMessage NOTIFY inlineMessageChanged)
     Q_PROPERTY(QString distroName READ distroName CONSTANT)
@@ -94,7 +95,6 @@ public:
     }
     bool hasSecurityUpdates() const;
 
-    bool isBusy() const;
     bool isInitializing() const;
 
     Q_SCRIPTABLE bool isExtended(const QString &id);
@@ -124,6 +124,7 @@ public:
     {
         return m_inlineMessage.data();
     }
+    QString remainingDescription() const;
 
 public Q_SLOTS:
     void installApplication(AbstractResource *app, const AddonList &addons);
@@ -156,6 +157,7 @@ private:
     bool addResourcesBackend(AbstractResourcesBackend *backend);
     void registerBackendByName(const QString &name);
     void initApplicationsBackend();
+    void destroyObject();
 
     bool m_isInitializing = true;
     QVector<AbstractResourcesBackend *> m_backends;
@@ -168,4 +170,5 @@ private:
     QSharedPointer<InlineMessage> m_inlineMessage;
 
     static ResourcesModel *s_self;
+    static bool s_quitting;
 };
